@@ -25,9 +25,9 @@ here = os.getcwd()
 hostname = socket.gethostname()
 
 config = dict(
-    sign_messages=True,
+    sign_messages=False,
     validate_signatures=False,
-    ssldir=SEP.join([here, 'dev_certs/keys']),
+    ssldir="/etc/pki/fedmsg",
 
     crl_location="https://fedoraproject.org/fedmsg/crl.pem",
     crl_cache="/tmp/crl.pem",
@@ -37,9 +37,5 @@ config = dict(
         # In prod/stg, map hostname to the name of the cert in ssldir.
         # Unfortunately, we can't use socket.getfqdn()
         #"app01.stg": "app01.stg.phx2.fedoraproject.org",
-        "shell.%s" % hostname: "shell-app01.phx2.fedoraproject.org",
-        "bodhi.%s" % hostname: "bodhi-app01.phx2.fedoraproject.org",
-        "fas.%s" % hostname: "fas-fas01.phx2.fedoraproject.org",
-        "fedoratagger.%s" % hostname: "fedoratagger-packages01.phx2.fedoraproject.org",
     },
 )
